@@ -188,17 +188,12 @@ class Rawls():
                             "` extension..")
 
         # check if necessary to construct output folder
-        folder_path = outfile.split('/')
+        folder_path = os.path.split(outfile)
 
-        if len(folder_path) > 1:
-            del folder_path[-1]
+        if len(folder_path[0]) > 1:
 
-            output_path = ''
-            for folder in folder_path:
-                output_path = os.path.join(output_path, folder)
-
-            if not os.path.exists(output_path):
-                os.makedirs(output_path)
+            if not os.path.exists(folder_path[0]):
+                os.makedirs(folder_path[0])
 
         # save image using specific extension
         if extension == 'rawls':
@@ -214,7 +209,7 @@ class Rawls():
             f.write(b'COMMENTS\n')
             f.write(bytes(self.details.to_rawls() + '\n', 'utf-8'))
 
-            # save additionnals data
+            # save additionnals comments data
             for key, value in self.details.additionals.items():
                 add_str = '#{0} {1}'.format(key, value)
                 f.write(bytes(add_str + '\n', 'utf-8'))
@@ -311,7 +306,7 @@ class Rawls():
 
             self.gamma_converted = True
 
-    def add_comments(self, key, value):
+    def add_comment(self, key, value):
         """Add additionals comments into `.rawls` file
 
         Args:
@@ -329,7 +324,7 @@ class Rawls():
                 '`{}` key already exists into additionnals details'.format(
                     key))
 
-    def del_comments(self, key):
+    def del_comment(self, key):
         """Delete additionals comments into `.rawls` file
 
         Args:
@@ -387,6 +382,7 @@ class Rawls():
             gamma_convert: {bool} -- necessary or not to convert using gamma (default: True)
         """
 
+        # TODO : improve this part
         if '/' in outfile:
             folders = outfile.split('/')
             del folders[-1]
